@@ -1,3 +1,6 @@
+# Copyright: 2011, Grigoriy Petukhov
+# Author: Grigoriy Petukhov (http://lorien.name)
+# License: BSD
 from datetime import datetime
 
 from django.db.models.signals import post_save
@@ -12,15 +15,13 @@ def post_saved(instance, created, **kwargs):
     if created:
         notify_topic_subscribers(instance)
 
-        now = datetime.now()
-
-        instance.topic.updated = now
+        instance.topic.updated = instance.created
         instance.topic.last_post = instance
         instance.topic.post_count += 1
         instance.topic.save()
 
         forum = instance.topic.forum
-        forum.updated = now
+        forum.updated = instance.created
         forum.last_post = instance
         forum.post_count += 1
         forum.save()
